@@ -22,9 +22,10 @@ SOFTWARE.'''
 
 import json
 import pytest
-from fluids.numerics import assert_close, assert_close1d, assert_close2d
+from fluids.numerics import assert_close, assert_close1d, assert_close2d, linspace
 from fluids.constants import R
 from chemicals.utils import ws_to_zs
+import chemicals
 from thermo.thermal_conductivity import *
 from thermo.viscosity import ViscosityGas
 from thermo.mixture import Mixture
@@ -140,6 +141,29 @@ def test_ThermalConductivityLiquid():
     assert hash(EtOH) == hash0
     assert hash(EtOH2) == hash0
 
+@pytest.mark.fitting
+@pytest.mark.meta_T_dept
+def test_ThermalConductivityLiquid_fitting0():
+    ammonia_Ts_kg = [200, 236.842, 239.82, 273.684, 310.526, 347.368, 384.211, 421.053, 457.895, 494.737, 531.579, 568.421, 605.263, 642.105, 678.947, 715.789, 752.632, 789.474, 826.316, 863.158, 900, ]
+    ammonia_kgs = [0.0146228, 0.0182568, 0.0185644, 0.0221923, 0.0263847, 0.0308034, 0.0354254, 0.040233, 0.0452116, 0.0503493, 0.0556358, 0.0610625, 0.0666218, 0.072307, 0.0781123, 0.0840323, 0.0900624, 0.0961983, 0.102436, 0.108772, 0.115203]
+    
+    # note: equation does not yet support numba
+    fit, res = ThermalConductivityLiquid.fit_data_to_model(Ts=ammonia_Ts_kg, data=ammonia_kgs, model='DIPPR102',
+                          do_statistics=True, use_numba=False, fit_method='lm')
+    assert res['MAE'] < 1e-5
+
+@pytest.mark.slow
+@pytest.mark.fuzz
+@pytest.mark.fitting
+@pytest.mark.meta_T_dept
+def test_ThermalConductivityLiquid_fitting1_dippr100():
+    for i, CAS in enumerate(chemicals.thermal_conductivity.k_data_Perrys_8E_2_315.index):
+        obj = ThermalConductivityLiquid(CASRN=CAS)
+        Ts = linspace(obj.Perrys2_315_Tmin, obj.Perrys2_315_Tmax, 10)
+        props_calc = [obj.calculate(T, DIPPR_PERRY_8E) for T in Ts]
+        res, stats = obj.fit_data_to_model(Ts=Ts, data=props_calc, model='DIPPR100',
+                                           do_statistics=True, use_numba=False, fit_method='lm')
+        assert stats['MAE'] < 1e-8
 
 @pytest.mark.CoolProp
 @pytest.mark.meta_T_dept
@@ -232,7 +256,20 @@ def test_ThermalConductivityGas():
 
     assert ThermalConductivityGas.from_json(EtOH.as_json()) == EtOH
 
-
+@pytest.mark.fitting
+@pytest.mark.meta_T_dept
+def test_ThermalConductivityGas_fitting0():
+    try_CASs_dippr = ['106-97-8', '142-29-0', '565-59-3', '74-83-9', '115-21-9', 
+                      '78-78-4', '111-27-3', '74-90-8', '64-17-5', '50-00-0', '74-98-6',
+                      '7664-39-3', '107-21-1', '592-76-7', '115-07-1', '64-19-7']
+    for CAS in try_CASs_dippr:
+        obj = ThermalConductivityGas(CASRN=CAS)
+        Ts = linspace(obj.Perrys2_314_Tmin, obj.Perrys2_314_Tmax, 10)
+        props_calc = [obj.calculate(T, DIPPR_PERRY_8E) for T in Ts]
+        res, stats = obj.fit_data_to_model(Ts=Ts, data=props_calc, model='DIPPR102', multiple_tries=True,
+                              do_statistics=True, use_numba=False, fit_method='lm')
+        assert stats['MAE'] < 1e-5
+    
 def test_ThermalConductivityGasMixture():
     T, P = 298.15, 101325.0
     MWs = [28.0134, 39.948, 31.9988]
