@@ -241,7 +241,10 @@ if not numerics.is_micropython:
                   phases, phases.air_phase, phases.ceos, phases.combined, 
                   phases.coolprop_phase, phases.gibbs_excess, phases.helmholtz_eos,
                   phases.iapws_phase, phases.ideal_gas, phases.petroleum, 
-                  phases.phase, phases.phase_utils, phases.virial_phase]
+                  phases.phase, phases.phase_utils, phases.virial_phase,
+                  utils.functional, utils.mixture_property,
+                  utils.t_dependent_property, utils.tp_dependent_property,
+                  utils.multi_cheb_1d]
     
     def complete_lazy_loading():
         import chemicals
@@ -286,6 +289,6 @@ try:
 except:
     thermo_dir = ''
 
-__version__ = '0.2.7'
+__version__ = '0.2.8'
 
 
