@@ -320,13 +320,11 @@ class EnthalpyVaporization(TDependentProperty):
         to reset the parameters.
         '''
         methods = []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if has_CoolProp() and self.CASRN in coolprop_dict:
                 methods.append(COOLPROP)
                 self.CP_f = coolprop_fluids[self.CASRN]
-                Tmins.append(self.CP_f.Tt); Tmaxs.append(self.CP_f.Tc)
                 T_limits[COOLPROP] = (self.CP_f.Tt, self.CP_f.Tc*.9999)
             if self.CASRN in miscdata.VDI_saturation_dict:
                 methods.append(VDI_TABULAR)
@@ -334,13 +332,11 @@ class EnthalpyVaporization(TDependentProperty):
                 self.VDI_Tmin = Ts[0]
                 self.VDI_Tmax = Ts[-1]
                 self.tabular_data[VDI_TABULAR] = (Ts, props)
-                Tmins.append(self.VDI_Tmin); Tmaxs.append(self.VDI_Tmax)
                 T_limits[VDI_TABULAR] = (self.VDI_Tmin, self.VDI_Tmax)
 
             if self.CASRN in phase_change.phase_change_data_Alibakhshi_Cs.index and self.Tc is not None:
                 methods.append(ALIBAKHSHI)
                 self.Alibakhshi_C = float(phase_change.phase_change_data_Alibakhshi_Cs.at[self.CASRN, 'C'])
-                Tmaxs.append( max(self.Tc-100., 0) )
                 T_limits[ALIBAKHSHI] = (self.Tc*.3, max(self.Tc-100., 0))
             if self.CASRN in phase_change.Hvap_data_CRC.index and not isnan(phase_change.Hvap_data_CRC.at[self.CASRN, 'HvapTb']):
                 methods.append(CRC_HVAP_TB)
@@ -368,32 +364,25 @@ class EnthalpyVaporization(TDependentProperty):
                 methods.append(DIPPR_PERRY_8E)
                 Tc, C1, C2, C3, C4, self.Perrys2_150_Tmin, self.Perrys2_150_Tmax = phase_change.phase_change_values_Perrys2_150[phase_change.phase_change_data_Perrys2_150.index.get_loc(self.CASRN)].tolist()
                 self.Perrys2_150_coeffs = [Tc, C1, C2, C3, C4]
-                Tmins.append(self.Perrys2_150_Tmin); Tmaxs.append(self.Perrys2_150_Tmax)
                 T_limits[DIPPR_PERRY_8E] = (self.Perrys2_150_Tmin, self.Perrys2_150_Tmax)
             if self.CASRN in phase_change.phase_change_data_VDI_PPDS_4.index:
                 Tc, A, B, C, D, E = phase_change.phase_change_values_VDI_PPDS_4[phase_change.phase_change_data_VDI_PPDS_4.index.get_loc(self.CASRN)].tolist()
                 self.VDI_PPDS_coeffs = [A, B, C, D, E]
                 self.VDI_PPDS_Tc = Tc
                 methods.append(VDI_PPDS)
-                Tmaxs.append(self.VDI_PPDS_Tc);
                 T_limits[VDI_PPDS] = (0.1*self.VDI_PPDS_Tc, self.VDI_PPDS_Tc)
         if all((self.Tc, self.omega)):
             methods.extend(self.CSP_methods)
-            Tmaxs.append(self.Tc); Tmins.append(0)
             for m in self.CSP_methods:
                 T_limits[m] = (1e-4, self.Tc)
         if all((self.Tc, self.Pc)):
             methods.append(CLAPEYRON)
-            Tmaxs.append(self.Tc); Tmins.append(0)
             T_limits[CLAPEYRON] = (1e-4, self.Tc)
         if all((self.Tb, self.Tc, self.Pc)):
             methods.extend(self.boiling_methods)
-            Tmaxs.append(self.Tc); Tmins.append(0)
             for m in self.boiling_methods:
                 T_limits[m] = (1e-4, self.Tc)
         self.all_methods = set(methods)
-        if Tmins and Tmaxs:
-            self.Tmin, self.Tmax = min(Tmins), max(Tmaxs)
 
     @staticmethod
     def _method_indexes():
@@ -407,7 +396,9 @@ class EnthalpyVaporization(TDependentProperty):
                 VDI_PPDS: phase_change.phase_change_data_VDI_PPDS_4.index,
                 }
 
-
+    def _set_poly_fit(self, poly_fit):
+        self.poly_fit_Tc = poly_fit[2]
+        super()._set_poly_fit((poly_fit[0], poly_fit[1], poly_fit[3]))
 
     def calculate(self, T, method):
         r'''Method to calculate heat of vaporization of a liquid at
@@ -452,9 +443,9 @@ class EnthalpyVaporization(TDependentProperty):
         elif method == PITZER:
             Hvap = Pitzer(T, self.Tc, self.omega)
         elif method == CLAPEYRON:
-            Zg = self.Zg(T) if hasattr(self.Zg, '__call__') else self.Zg
-            Zl = self.Zl(T) if hasattr(self.Zl, '__call__') else self.Zl
-            Psat = self.Psat(T) if hasattr(self.Psat, '__call__') else self.Psat
+            Psat = self.Psat(T) if callable(self.Psat) else self.Psat
+            Zg = self.Zg(T, Psat) if callable(self.Zg) else self.Zg
+            Zl = self.Zl(T, Psat) if callable(self.Zl) else self.Zl
             if Zg:
                 if Zl:
                     dZ = Zg-Zl
@@ -533,7 +524,7 @@ class EnthalpyVaporization(TDependentProperty):
                     validity = False
             else:
                 validity = T <= self.Tc
-        elif method in [CRC_HVAP_298, GHARAGHEIZI_HVAP_298]:
+        elif method in (CRC_HVAP_298, GHARAGHEIZI_HVAP_298):
             if not self.Tc:
                 if T < 298.15 - 5 or T > 298.15 + 5:
                     validity = False
@@ -550,19 +541,12 @@ class EnthalpyVaporization(TDependentProperty):
                 validity = False
 #            elif (self.Tb and T < self.Tb - 50):
 #                validity = False
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    validity = False
-        elif method == POLY_FIT:
-            validity = True
+
         elif method == CLAPEYRON:
             if not (self.Psat and T < self.Tc):
                 validity = False
         else:
-            raise Exception('Method not valid')
+            return super(EnthalpyVaporization, self).test_method_validity(T, method)
         return validity
 
 ### Heat of Sublimation
@@ -697,7 +681,6 @@ class EnthalpySublimation(TDependentProperty):
         to reset the parameters.
         '''
         methods = []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if self.CASRN in phase_change.Hsub_data_Gharagheizi.index:
@@ -713,15 +696,7 @@ class EnthalpySublimation(TDependentProperty):
                     T_limits[CRC_HFUS_HVAP_TM] = (self.Tm, self.Tm)
                 else:
                     T_limits[CRC_HFUS_HVAP_TM] = (298.15, 298.15)
-        try:
-            Tmins.append(0.01*self.Tm)
-            Tmaxs.append(self.Tm)
-            Tmaxs.append(self.Tt)
-        except:
-            pass
         self.all_methods = set(methods)
-        if Tmins and Tmaxs:
-            self.Tmin, self.Tmax = min(i for i in Tmins if i is not None), max(i for i in Tmaxs if i is not None)
 
     @staticmethod
     def _method_indexes():
@@ -804,19 +779,9 @@ class EnthalpySublimation(TDependentProperty):
             Whether or not a method is valid
         '''
         validity = True
-        if method == POLY_FIT:
+        if method in (GHARAGHEIZI_HSUB_298, GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM):
             validity = True
-        elif method in (GHARAGHEIZI_HSUB_298, GHARAGHEIZI_HSUB, CRC_HFUS_HVAP_TM):
-            validity = True
-        elif method == POLY_FIT:
-            validity = True
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    validity = False
         else:
-            raise Exception('Method not valid')
+            return super(EnthalpySublimation, self).test_method_validity(T, method)
         return validity
 
