@@ -340,7 +340,6 @@ class ThermalConductivityLiquid(TPDependentProperty):
         to reset the parameters.
         '''
         methods, methods_P = [], []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if self.CASRN in miscdata.VDI_saturation_dict:
@@ -349,20 +348,17 @@ class ThermalConductivityLiquid(TPDependentProperty):
                 self.VDI_Tmin = Ts[0]
                 self.VDI_Tmax = Ts[-1]
                 self.tabular_data[VDI_TABULAR] = (Ts, props)
-                Tmins.append(self.VDI_Tmin); Tmaxs.append(self.VDI_Tmax)
                 T_limits[VDI_TABULAR] = (self.VDI_Tmin, self.VDI_Tmax)
             if has_CoolProp() and self.CASRN in coolprop_dict:
                 CP_f = coolprop_fluids[self.CASRN]
                 if CP_f.has_k:
                     self.CP_f = CP_f
                     methods.append(COOLPROP); methods_P.append(COOLPROP)
-                    Tmins.append(self.CP_f.Tmin); Tmaxs.append(self.CP_f.Tc)
                     T_limits[COOLPROP] = (self.CP_f.Tmin*1.001, self.CP_f.Tc*0.9999)
             if self.CASRN in thermal_conductivity.k_data_Perrys_8E_2_315.index:
                 methods.append(DIPPR_PERRY_8E)
                 C1, C2, C3, C4, C5, self.Perrys2_315_Tmin, self.Perrys2_315_Tmax = thermal_conductivity.k_values_Perrys_8E_2_315[thermal_conductivity.k_data_Perrys_8E_2_315.index.get_loc(self.CASRN)].tolist()
                 self.Perrys2_315_coeffs = [C1, C2, C3, C4, C5]
-                Tmins.append(self.Perrys2_315_Tmin); Tmaxs.append(self.Perrys2_315_Tmax)
                 T_limits[DIPPR_PERRY_8E] = (self.Perrys2_315_Tmin, self.Perrys2_315_Tmax)
             if self.CASRN in thermal_conductivity.k_data_VDI_PPDS_9.index:
                 A, B, C, D, E = thermal_conductivity.k_values_VDI_PPDS_9[thermal_conductivity.k_data_VDI_PPDS_9.index.get_loc(self.CASRN)].tolist()
@@ -381,13 +377,12 @@ class ThermalConductivityLiquid(TPDependentProperty):
             # where it becomes 0.
         if all([self.MW, self.Tm]):
             methods.append(SHEFFY_JOHNSON)
-            Tmins.append(0); Tmaxs.append(self.Tm + 793.65)
             T_limits[SHEFFY_JOHNSON] = (1e-3, self.Tm + 793.65)
             # Works down to 0, has a nice limit at T = Tm+793.65 from Sympy
         if all([self.Tb, self.Pc, self.omega]):
             methods.append(GHARAGHEIZI_L)
-            T_limits[GHARAGHEIZI_L] = (self.Tb, self.Tc)
-            Tmins.append(self.Tb); Tmaxs.append(self.Tc)
+            Tmax = 10000. if self.Tc is None else self.Tc 
+            T_limits[GHARAGHEIZI_L] = (self.Tb, Tmax)
             # Chosen as the model is weird
         if all([self.Tc, self.Pc, self.omega]):
             methods.append(NICOLA)
@@ -402,8 +397,6 @@ class ThermalConductivityLiquid(TPDependentProperty):
             methods_P.extend([DIPPR_9G, MISSENARD])
         self.all_methods = set(methods)
         self.all_methods_P = set(methods_P)
-        if Tmins and Tmaxs:
-            self.Tmin, self.Tmax = min(Tmins), max(Tmaxs)
         for m in self.ranked_methods_P:
             if m in self.all_methods_P:
                 self.method_P = m
@@ -536,14 +529,14 @@ class ThermalConductivityLiquid(TPDependentProperty):
             if T > self.Tc:
                 return False
                 # Doesn't run, no lower limit though
-        elif method in [GHARAGHEIZI_L, NICOLA, NICOLA_ORIGINAL]:
+        elif method in (GHARAGHEIZI_L, NICOLA, NICOLA_ORIGINAL):
             if T > self.Tc*1.5:
                 return False
             # No lower limit, give a wide margin of acceptability here
         elif method == DIPPR_PERRY_8E:
             if T < self.Perrys2_315_Tmin or T > self.Perrys2_315_Tmax:
                 return False
-        elif method in [BAHADORI_L, LAKSHMI_PRASAD, SHEFFY_JOHNSON]:
+        elif method in (BAHADORI_L, LAKSHMI_PRASAD, SHEFFY_JOHNSON):
             pass
             # no limits at all
         elif method == VDI_PPDS:
@@ -552,14 +545,8 @@ class ThermalConductivityLiquid(TPDependentProperty):
         elif method == COOLPROP:
             if T < self.CP_f.Tt or T > self.CP_f.Tc:
                 return False
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    return False
         else:
-            raise Exception('Method not valid')
+            return super(ThermalConductivityLiquid, self).test_method_validity(T, method)
         return True
 
     def test_method_validity_P(self, T, P, method):
@@ -599,13 +586,8 @@ class ThermalConductivityLiquid(TPDependentProperty):
                 validity = False
         elif method == COOLPROP:
             validity = PhaseSI('T', T, 'P', P, self.CASRN) in ['liquid', 'supercritical_liquid']
-        elif method in self.tabular_data:
-            if not self.tabular_extrapolation_permitted:
-                Ts, Ps, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1] or P < Ps[0] or P > Ps[-1]:
-                    validity = False
         else:
-            raise Exception('Method not valid')
+            return super(ThermalConductivityLiquid, self).test_method_validity_P(T, P, method)
         return validity
 
 MAGOMEDOV = 'MAGOMEDOV'
@@ -1033,7 +1015,6 @@ class ThermalConductivityGas(TPDependentProperty):
         to reset the parameters.
         '''
         methods, methods_P = [], []
-        Tmins, Tmaxs = [], []
         self.T_limits = T_limits = {}
         if load_data:
             if self.CASRN in miscdata.VDI_saturation_dict:
@@ -1042,20 +1023,17 @@ class ThermalConductivityGas(TPDependentProperty):
                 self.VDI_Tmin = Ts[0]
                 self.VDI_Tmax = Ts[-1]
                 self.tabular_data[VDI_TABULAR] = (Ts, props)
-                Tmins.append(self.VDI_Tmin); Tmaxs.append(self.VDI_Tmax)
                 T_limits[VDI_TABULAR] = (self.VDI_Tmin, self.VDI_Tmax)
             if has_CoolProp() and self.CASRN in coolprop_dict:
                 CP_f = coolprop_fluids[self.CASRN]
                 if CP_f.has_k:
                     self.CP_f = CP_f
                     methods.append(COOLPROP); methods_P.append(COOLPROP)
-                    Tmins.append(self.CP_f.Tmin); Tmaxs.append(self.CP_f.Tc)
                     T_limits[COOLPROP] = (self.CP_f.Tmin, self.CP_f.Tc*0.9999)
             if self.CASRN in thermal_conductivity.k_data_Perrys_8E_2_314.index:
                 methods.append(DIPPR_PERRY_8E)
                 C1, C2, C3, C4, self.Perrys2_314_Tmin, self.Perrys2_314_Tmax = thermal_conductivity.k_values_Perrys_8E_2_314[thermal_conductivity.k_data_Perrys_8E_2_314.index.get_loc(self.CASRN)].tolist()
                 self.Perrys2_314_coeffs = [C1, C2, C3, C4]
-                Tmins.append(self.Perrys2_314_Tmin); Tmaxs.append(self.Perrys2_314_Tmax)
                 T_limits[DIPPR_PERRY_8E] = (self.Perrys2_314_Tmin, self.Perrys2_314_Tmax)
             if self.CASRN in thermal_conductivity.k_data_VDI_PPDS_10.index:
                 A, B, C, D, E = thermal_conductivity.k_values_VDI_PPDS_10[thermal_conductivity.k_data_VDI_PPDS_10.index.get_loc(self.CASRN)].tolist()
@@ -1066,24 +1044,19 @@ class ThermalConductivityGas(TPDependentProperty):
         if all((self.MW, self.Tb, self.Pc, self.omega)):
             methods.append(GHARAGHEIZI_G)
             # Turns negative at low T; do not set Tmin
-            Tmaxs.append(3000)
             T_limits[GHARAGHEIZI_G] = (1e-3, 3000.0)
         if all((self.Cpgm, self.mug, self.MW, self.Tc)):
             methods.append(DIPPR_9B)
-            Tmins.append(0.01); Tmaxs.append(1E4)  # No limit here
             T_limits[DIPPR_9B] = (1e-2, 1e4)
         if all((self.Cpgm, self.mug, self.MW, self.Tc, self.omega)):
             methods.append(CHUNG)
-            Tmins.append(0.01); Tmaxs.append(1E4)  # No limit
             T_limits[CHUNG] = (1e-2, 1e4)
         if all((self.Cpgm, self.MW, self.Tc, self.Vc, self.Zc, self.omega)):
             methods.append(ELI_HANLEY)
-            Tmaxs.append(1E4)  # Numeric error at low T
             T_limits[ELI_HANLEY] = (self.Tc*0.4, 1e4)
         if all((self.Cpgm, self.mug, self.MW)):
             methods.append(EUCKEN_MOD)
             methods.append(EUCKEN)
-            Tmins.append(0.01); Tmaxs.append(1E4)  # No limits
             T_limits[EUCKEN] = T_limits[EUCKEN_MOD] = (1e-2, 1e4)
         if self.MW:
             methods.append(BAHADORI_G)
@@ -1097,8 +1070,6 @@ class ThermalConductivityGas(TPDependentProperty):
             methods_P.append(STIEL_THODOS_DENSE)
         self.all_methods = set(methods)
         self.all_methods_P = set(methods_P)
-        if Tmins and Tmaxs:
-            self.Tmin, self.Tmax = min(Tmins), max(Tmaxs)
         for m in self.ranked_methods_P:
             if m in self.all_methods_P:
                 self.method_P = m
@@ -1236,8 +1207,8 @@ class ThermalConductivityGas(TPDependentProperty):
         validity : bool
             Whether or not a method is valid
         '''
-        if method in [GHARAGHEIZI_G, DIPPR_9B, CHUNG, ELI_HANLEY, EUCKEN_MOD,
-                      EUCKEN, BAHADORI_G, VDI_PPDS]:
+        if method in (GHARAGHEIZI_G, DIPPR_9B, CHUNG, ELI_HANLEY, EUCKEN_MOD,
+                      EUCKEN, BAHADORI_G, VDI_PPDS):
             pass
         elif method == DIPPR_PERRY_8E:
             if T < self.Perrys2_314_Tmin or T > self.Perrys2_314_Tmax:
@@ -1245,14 +1216,8 @@ class ThermalConductivityGas(TPDependentProperty):
         elif method == COOLPROP:
             if T < self.CP_f.Tmin or T > self.CP_f.Tmax:
                 return False
-        elif method in self.tabular_data:
-            # if tabular_extrapolation_permitted, good to go without checking
-            if not self.tabular_extrapolation_permitted:
-                Ts, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1]:
-                    return False
         else:
-            raise Exception('Method not valid')
+            return super(ThermalConductivityGas, self).test_method_validity(T, method)
         return True
 
     def test_method_validity_P(self, T, P, method):
@@ -1284,7 +1249,7 @@ class ThermalConductivityGas(TPDependentProperty):
             Whether or not a method is valid
         '''
         validity = True
-        if method in [ELI_HANLEY_DENSE, CHUNG_DENSE, STIEL_THODOS_DENSE]:
+        if method in (ELI_HANLEY_DENSE, CHUNG_DENSE, STIEL_THODOS_DENSE):
             if T < 0 or P < 0:
                 validity = False
             # no better checks known
@@ -1293,13 +1258,8 @@ class ThermalConductivityGas(TPDependentProperty):
                 return False
             else:
                 return PhaseSI('T', T, 'P', P, self.CASRN) in ['gas', 'supercritical_gas', 'supercritical', 'supercritical_liquid']
-        elif method in self.tabular_data:
-            if not self.tabular_extrapolation_permitted:
-                Ts, Ps, properties = self.tabular_data[method]
-                if T < Ts[0] or T > Ts[-1] or P < Ps[0] or P > Ps[-1]:
-                    validity = False
         else:
-            raise Exception('Method not valid')
+            return super(ThermalConductivityGas, self).test_method_validity_P(T, P, method)
         return validity
 
 
